package betterquesting.storage;

import betterquesting.api.properties.NativeProps;
import betterquesting.api.storage.ILifeDatabase;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.util.MathHelper;

/* loaded from: betterquesting_storage.jar:betterquesting/storage/LifeDatabase.class */
public final class LifeDatabase implements ILifeDatabase {
    public static final LifeDatabase INSTANCE = new LifeDatabase();
    private final HashMap<UUID, Integer> playerLives = new HashMap<>();

    public /* bridge */ /* synthetic */ NBTBase writeToNBT(NBTBase nBTBase, @Nullable List list) {
        return writeToNBT((NBTTagCompound) nBTBase, (List<UUID>) list);
    }

    public synchronized int getLives(@Nonnull UUID uuid) {
        return this.playerLives.computeIfAbsent(uuid, k -> {
            return (Integer) QuestSettings.INSTANCE.getProperty(NativeProps.LIVES_DEF);
        }).intValue();
    }

    public synchronized void setLives(@Nonnull UUID uuid, int value) {
        this.playerLives.put(uuid, Integer.valueOf(MathHelper.func_76125_a(value, 0, ((Integer) QuestSettings.INSTANCE.getProperty(NativeProps.LIVES_MAX)).intValue())));
    }

    public synchronized NBTTagCompound writeToNBT(NBTTagCompound nbt, @Nullable List<UUID> users) {
        NBTTagList jul = new NBTTagList();
        for (Map.Entry<UUID, Integer> entry : this.playerLives.entrySet()) {
            if (users == null || users.contains(entry.getKey())) {
                NBTTagCompound j = new NBTTagCompound();
                j.func_74778_a("uuid", entry.getKey().toString());
                j.func_74768_a("lives", entry.getValue().intValue());
                jul.func_74742_a(j);
            }
        }
        nbt.func_74782_a("playerLives", jul);
        return nbt;
    }

    public synchronized void readFromNBT(NBTTagCompound nbt, boolean merge) {
        if (!merge) {
            this.playerLives.clear();
        }
        NBTTagList tagList = nbt.func_150295_c("playerLives", 10);
        for (int i = 0; i < tagList.func_74745_c(); i++) {
            NBTTagCompound j = tagList.func_150305_b(i);
            try {
                UUID uuid = UUID.fromString(j.func_74779_i("uuid"));
                int lives = j.func_74762_e("lives");
                this.playerLives.put(uuid, Integer.valueOf(lives));
            } catch (Exception e) {
            }
        }
    }

    public synchronized void reset() {
        this.playerLives.clear();
    }
}
